#
# spec file for package bctoolbox
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   1
Name:           bctoolbox
Version:        5.3.105
Release:        1.1
Summary:        Utility library for software from Belledonne Communications
License:        GPL-3.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://linphone.org/
Source:         https://gitlab.linphone.org/BC/public/bctoolbox/-/archive/%{version}/%{name}-%{version}.tar.bz2
Source1:        baselibs.conf
# PATCH-FIX-OPENSUSE bctoolbox-fix-pkgconfig.patch
Patch0:         bctoolbox-fix-pkgconfig.patch
Patch2:         set_curret_version.patch
BuildRequires:  bcunit-devel >= 5.3.0
%if 0%{?suse_version} >= 1600
# At the time of writing (11/Dec/2023), decaf is only available on Tumbleweed.
BuildRequires:  decaf-devel
%endif
BuildRequires:  chrpath
BuildRequires:  cmake >= 3.22
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(bcunit) >= 5.3.0
%if 0%{?suse_version} > 1600
BuildRequires:  pkgconfig(mbedtls) < 3.0.0
BuildRequires:  pkgconfig(mbedtls) >= 2.0.0
%else
BuildRequires:  mbedtls-devel
%endif
BuildRequires:  pkgconfig(zlib)

%description
Utilities library used by Belledonne Communications softwares like
belle-sip, mediastreamer2 and linphone.

%package devel
Summary:        Development files for %{name}, a utility library for linphone/belle-sip/etc
Group:          Development/Libraries/C and C++
Requires:       cmake
Requires:       lib%{name}%{sover} = %{version}
Requires:       lib%{name}-tester%{sover} = %{version}
Requires:       mbedtls-devel < 3

%description devel
Utilities library used by Belledonne Communications softwares like
belle-sip, mediastreamer2 and linphone.

This package contains development files.

%package -n lib%{name}%{sover}
Summary:        Utility library for software from Belledonne Communications
Group:          Development/Libraries/C and C++

%description -n lib%{name}%{sover}
Utilities library used by Belledonne Communications softwares like
belle-sip, mediastreamer2 and linphone.

This package the contains shared library.

%package -n lib%{name}-tester%{sover}
Summary:        Utility library for software from Belledonne Communications
Group:          Development/Libraries/C and C++

%description -n lib%{name}-tester%{sover}
Utilities library used by Belledonne Communications softwares like
belle-sip, mediastreamer2 and linphone.

This package the contains shared library for testing component.

%prep
%autosetup -p1

%build
export CFLAGS=$(echo "$CFLAGS -Wno-error=maybe-uninitialized -Wno-error=unused-parameter")
export CXXFLAGS=$(echo "$CXXFLAGS -Wno-error=maybe-uninitialized -Wno-error=unused-parameter")
%cmake \
  -DENABLE_STATIC=OFF
%cmake_build

%install
%cmake_install
chrpath -d %{buildroot}%{_libdir}/lib%{name}.so.%{sover}* %{buildroot}%{_libdir}/lib%{name}-tester.so.%{sover}* %{buildroot}%{_bindir}/bctoolbox-tester

%post -n lib%{name}%{sover} -p /sbin/ldconfig
%postun -n lib%{name}%{sover} -p /sbin/ldconfig
%post -n lib%{name}-tester%{sover} -p /sbin/ldconfig
%postun -n lib%{name}-tester%{sover} -p /sbin/ldconfig

%files -n lib%{name}%{sover}
%license LICENSE.txt
%{_libdir}/lib%{name}.so.%{sover}*

%files -n lib%{name}-tester%{sover}
%license LICENSE.txt
%{_bindir}/bctoolbox-tester
%{_libdir}/lib%{name}-tester.so.%{sover}*

%files devel
%license LICENSE.txt
%doc README.md
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/lib%{name}.so
%{_includedir}/%{name}/
%{_libdir}/lib%{name}-tester.so
%{_libdir}/pkgconfig/bctoolbox-tester.pc
%dir %{_datadir}/BCToolbox
%dir %{_datadir}/BCToolbox/cmake
%{_datadir}/BCToolbox/cmake/*.cmake
%{_datadir}/BCToolbox/cmake/gitversion.h.in

%changelog
* Mon Feb 17 2025 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.3.105 (no changelog).
* Mon Nov 11 2024 ecsos <ecsos@opensuse.org>
- Update to 5.3.95 (no changelog).
* Sun Oct 13 2024 ecsos <ecsos@opensuse.org>
- Update to 5.3.89 (no changelog).
* Fri Mar 29 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.3.37 (no changelog).
* Thu Mar  7 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.3.26 (no changelog)
* Mon Jan 15 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.3.7 (no changelog)
- Removed no longer needed gcc9-stringop-bogus-warning.patch
* Mon Dec 11 2023 Paolo Stivanin <info@paolostivanin.com>
- Add decaf dep for post quantum crypto (tumbleweed only for now).
* Sun Oct  8 2023 i thod <thod_@gmx.de>
- Remove RPATH to be able to build on Fedora
* Mon Aug 28 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.2.98 (no changelog)
* Wed Jun 28 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.2.73 (no changelog)
* Wed May  3 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Also set the devel-package dependency on mbedtls-devel to < 3: no
  need to try to build bctoolbox consumers with mbedtls 3.x.
* Wed May  3 2023 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Require the mbedtls-devel version to be lower than 3.0.0
* Fri Apr  7 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.2.49 (no changelog)
* Wed Mar  8 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.2.30 (no changelog)
- Add set_curret_version.patch
* Tue Feb 14 2023 Avinesh Kumar <avinesh.kumar@suse.com>
- Update to version 5.2.16:
  * minor changes
* Wed Jan 11 2023 Giacomo Comes <gcomes.obs@gmail.com> - 5.2.9
- Update to version 5.2.9:
  * no changes
- revert license tag change
* Wed Jan  4 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.2.6:
  * Crypto: add support for post-quantum algorithms.
  * Minor changes.
* Mon Oct 17 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.1.64 (no changelog).
* Sun Aug 14 2022 thod_@gmx.de
- Remove RPATH to be able to build on Fedora
* Fri Jul  8 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to release 5.1.45:
  * fix gcc12 warnings
  * fix doc generation
* Tue Jun  7 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 5.1.38
  * Fix wrong read variable resulting by always being in
    "snapshots" state
* Tue Apr 26 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 5.1.17
  * No changes for Linux platforms
* Thu Mar 24 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to version 5.1.12:
  * Add an API to switch off logs on regex test.
  * Fix an issue where STUN gathering requests could be sent over
    IPv6 instead of IPv4 for which they are more useful.
* Tue Mar  1 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to version 5.1.0:
  * new vfs read2/write2 functions without offset parameter,
    to easy mapping with standard libc functions.
  * optimized C++ logging macros.
* Tue Feb  1 2022 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.67
- Update to version 5.0.67:
  * no changes
- fix license tag
* Tue Jan 18 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to version 5.0.66:
  * no changelog
* Sun Nov 21 2021 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.53
- Update to version 5.0.53:
  * no changes
* Mon Nov  8 2021 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.49
- Update to 5.0.49:
  * no changes
* Tue Nov  2 2021 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.46
- Update to 5.0.46:
  * no changes
* Tue Oct 19 2021 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.36
- Update to 5.0.36:
  * no changes
- removed workaround for building with GCC11
* Fri Oct 15 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.0.35:
  * no changelog
* Fri Jul 30 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.0.3:
  * no changelog
* Wed Jul 14 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.0.0:
  * Tester API: add API to set maximum number of failed tests.
  * Few bugfixes
* Tue Jun 22 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.5.20
  * no changelog available
* Thu May 13 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 4.5.15
  * No changelog available
* Wed Apr 28 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.5.10 (no changelog available)
- Apply GCC11 workaround only on Factory/Tumbleweed
* Thu Apr 15 2021 Luiz Angelo Daros de Luca <luizluca@tre-sc.jus.br>
- Update to 4.5.3
  * No changelog available.
* Wed Apr  7 2021 Paolo Stivanin <info@paolostivanin.com>
- Workaround to allow building with GCC11
* Wed Mar 31 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.5.0:
  * Encrypted VFS API.
  * Callback for client certificate query is now passed with the full list of subjects.
  * miscellaneous small things
* Tue Mar  9 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.4.33 (no changelog)
* Mon Feb 22 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.4.29 (no changelog)
* Fri Jan 22 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.4.24 (no changelog)
* Thu Dec 31 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.4.21 (no changelog)
* Wed Dec  2 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.4.13 (no changelog)
* Thu Nov 12 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to version 4.4.7 (no changelog)
* Wed Nov  4 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to version 4.4.6 (no changelog)
* Fri Jun 26 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to version 4.4.0 (no changelog)
* Tue Mar  3 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to version 4.3.1 (no changelog)
* Mon Nov 18 2019 Simon Lees <sflees@suse.de>
- %%make_jobs is depricated replaced by %%cmake_build
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Tue Apr 30 2019 Martin Liška <mliska@suse.cz>
- Add gcc9-stringop-bogus-warning.patch in order to fix a misleading
  warning by GCC 9 (boo#1121200).
* Wed Aug 15 2018 sor.alexei@meowr.ru
- Remove bctoolbox-fix-no-git.patch: it is better to fix the issue
  in packages where it occurs.
* Thu Jul 20 2017 sor.alexei@meowr.ru
- Update to version 0.6.0:
  * Add API to escape/unescape strings (SIP, VCARD).
  * Bug fixes.
- Add bctoolbox-fix-pkgconfig.patch instead of requiring
  pkgconfig(bcunit) and pkgconfig(zlib).
- Add bctoolbox-fix-no-git.patch sor.alexei@meowr.ru: Fix building
  of dependent applications out-of-git.
* Wed Jun 21 2017 mpluskal@suse.com
- Update baselibs
- Run spec-cleaner
* Wed May 17 2017 sor.alexei@meowr.ru
- Update to version 0.5.1:
  * security bugfix: TLS session could be successfully established
    whereas the common name did not match the server name.
  * "const char * to void *" map feature.
- Remove bctoolbox-pkgconfig_1.patch and
  bctoolbox-pkgconfig_2.patch: fixed upstream.
* Sat Aug 27 2016 jengelh@inai.de
- Remove extraneous pkgconfig require
* Sat Aug 27 2016 mpluskal@suse.com
- Merge changes from home:X0F:HSF
- Fix generation of pkgconfig files
  * bctoolbox-pkgconfig_1.patch
  * bctoolbox-pkgconfig_2.patch
* Mon Aug 15 2016 jengelh@inai.de
- Update summary and rpm groups
* Fri Aug 12 2016 mpluskal@suse.com
- Initial package for version 0.2.0
